@@ -160,7 +160,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
         if self.context_semaphore.locked():
             self.context_semaphore.release()
-        logger.info("Re create browser: Completed")
+        logger.info(f"Re create browser: Completed with new context index {self.context_rotation_idx}")
 
     async def _create_page(self) -> Page:
         """Create a new page in a context, also creating a new context if necessary."""
@@ -249,6 +249,9 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         except PlaywrightTimeoutError:
             self.timeout_errors_in_row = self.timeout_errors_in_row + 1
             logger.error(f"[{request.url}] Request timeout while downloading request")
+            if self.timeout_errors_in_row > 2:
+                self.timeout_errors_in_row = 0
+                await self._plan_context_rotation()
             return Response('', status=504)
         except:
             logger.exception(f"[{request.url}] Error while downloading request")
@@ -268,9 +271,6 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
                     else:
                         if self.context_semaphore.locked():
                             self.context_semaphore.release()
-                        if self.timeout_errors_in_row > 3:
-                            self.timeout_errors_in_row = 0
-                            await self._plan_context_rotation()
                 else:
                     if self.context_semaphore.locked():
                         self.context_semaphore.release()
